==> image-data-domain-0.0.124-sources.jar: com/xforceplus/elephant/entity/TicketMachine.java <==
package com.xforceplus.elephant.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-31
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class TicketMachine implements Serializable {

  private static final long serialVersionUID=1L;

  private Long imageId;

  private String billCode;

  private String batchNo;

  private String warningStatus;

  private String warningInfo;

  private String exceptionStatus;

  private String exceptionInfo;

  private String checkStatus;

  private String checkRemark;

  private String checkTaskId;

  private LocalDateTime checkRequestTime;

  private LocalDateTime checkResponseTime;

  private Long checkUserId;

  private String checkUserName;

  private String isHooked;

  private Long xPoint;

  private Long yPoint;

  private Long width;

  private Long height;

  private Long angle;

  private String ticketCode;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private String isPublic;

  private String extFields;

  private String isReuse;

  private String ticketStatus;

  private String reserved1;

  private String reserved2;

  private String reserved3;

  private String isRepeat;

  private String repeatTag;

  private String createUserCode;

  private String systemOrig;

  private String billEntityCode;

  private String reuseTag;

  private String backStatus;

  private LocalDateTime backTime;

  private Long scanUserId;

  private String scanUserName;

  private String isSalesList;

  private String calculateStatus;

  private String relWarningInfo;

  private String relExceptionInfo;

  private String invoiceNo;

  private String invoiceCode;

  private String paperDrewDate;

  private String checkCode;

  private String invoiceSheet;

  private String purchaserName;

  private String purchaserTaxNo;

  private String purchaserAddress;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private String purchaserBankNameAccount;

  private String sellerName;

  private String sellerTaxNo;

  private String sellerAddress;

  private String sellerBankName;

  private String sellerBankAccount;

  private String sellerBankNameAccount;

  private String machineCode;

  private String category;

  private String networkNo;

  private String remark;

  /**
   * id
   */
  private Long id;

  /**
   * 租户id
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  /**
   * 创建人
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private Long ticketManyToOneImageId;




        }

==> image-data-domain-0.0.128-sources.jar: com/xforceplus/elephant/entity/TicketMachine.java <==
package com.xforceplus.elephant.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-08-03
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class TicketMachine implements Serializable {

  private static final long serialVersionUID=1L;

  private Long imageId;

  private String billCode;

  private String batchNo;

  private String warningStatus;

  private String warningInfo;

  private String exceptionStatus;

  private String exceptionInfo;

  private String checkStatus;

  private String checkRemark;

  private String checkTaskId;

  private LocalDateTime checkRequestTime;

  private LocalDateTime checkResponseTime;

  private Long checkUserId;

  private String checkUserName;

  private String isHooked;

  private Long xPoint;

  private Long yPoint;

  private Long width;

  private Long height;

  private Long angle;

  private String ticketCode;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private String isPublic;

  private String extFields;

  private String isReuse;

  private String ticketStatus;

  private String reserved1;

  private String reserved2;

  private String reserved3;

  private String isRepeat;

  private String repeatTag;

  private String createUserCode;

  private String systemOrig;

  private String billEntityCode;

  private String reuseTag;

  private String backStatus;

  private LocalDateTime backTime;

  private Long scanUserId;

  private String scanUserName;

  private String isSalesList;

  private String calculateStatus;

  private String relWarningInfo;

  private String relExceptionInfo;

  private String ticketCheckStatus;

  private String handleStatus;

  private String isCommit;

  private Long commitUserIs;

  private String commitUserName;

  private LocalDateTime commitTime;

  private LocalDateTime hookTime;

  private String invoiceNo;

  private String invoiceCode;

  private String paperDrewDate;

  private String checkCode;

  private String invoiceSheet;

  private String purchaserName;

  private String purchaserTaxNo;

  private String purchaserAddress;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private String purchaserBankNameAccount;

  private String sellerName;

  private String sellerTaxNo;

  private String sellerAddress;

  private String sellerBankName;

  private String sellerBankAccount;

  private String sellerBankNameAccount;

  private String machineCode;

  private String category;

  private String networkNo;

  private String remark;

  /**
   * id
   */
  private Long id;

  /**
   * 租户id
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  /**
   * 创建人
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private Long ticketManyToOneImageId;




        }
